@@ -49,5 +49,8 @@ def dispatch(factor: typing.Any, v: typing.Any) -> typing.Any:
     function, *returns = _from_signature(__name__, dispatch_map, (_aztype(v),))
     with numpy.errstate(all="ignore"):
         return v._wrap_result(
-            _flavor_of(v), function(v.lib, factor, *v.azimuthal.elements), returns, 1
+            _flavor_of(v),
+            function(v.lib, factor, *v.azimuthal.elements),
+            returns,
+            1,
         )
