@@ -1,16 +1,19 @@
-# Copyright (c) 2019-2021, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
+# Copyright (c) 2019-2024, Jonas Eschle, Jim Pivarski, Eduardo Rodrigues, and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
 
-import typing
-
 """
 .. code-block:: python
 
     Planar.unit(self)
 """
 
+from __future__ import annotations
+
+import typing
+from math import inf
+
 import numpy
 
 from vector._compute.planar import rho
@@ -25,7 +28,10 @@ from vector._methods import (
 
 def xy(lib, x, y):
     norm = rho.xy(lib, x, y)
-    return (lib.nan_to_num(x / norm, nan=0), lib.nan_to_num(y / norm, nan=0))
+    return (
+        lib.nan_to_num(x / norm, nan=0, posinf=inf, neginf=-inf),
+        lib.nan_to_num(y / norm, nan=0, posinf=inf, neginf=-inf),
+    )
 
 
 def rhophi(lib, rho, phi):
